@@ -12,7 +12,6 @@ def sendmsg(usr, msg, path='error', attach='error'):
     CHROME_PROFILE_PATH = "user-data-dir=C:\\Users\\HP\\AppData\\Local\\Google\\Chrome\\User Data\\Login"
     users = "error"
     mssg = "error"
-    # followupmssg = "error"
 
     try:
         if usr:
@@ -28,10 +27,6 @@ def sendmsg(usr, msg, path='error', attach='error'):
     except IndexError:
         print("Please Provide The Message File as 2st Argument")
 
-    # if followupmsg != 'error':
-    #     with open(followupmsg, 'r', encoding='utf8') as file:
-    #             followupmssg = file.read()
-
     options = webdriver.ChromeOptions()
     options.add_argument(CHROME_PROFILE_PATH)
 
@@ -74,24 +69,13 @@ def sendmsg(usr, msg, path='error', attach='error'):
                     image_box.send_keys(attach)
                     time.sleep(1)
 
-                    text_box = browser.find_element("xpath", '//div[@data-testid="pluggable-input-body"][@role="textbox"]')
+                    text_box = browser.find_element("xpath", '//div[@data-testid="media-caption-input-container"][@role="textbox"]')
                     pyperclip.copy(mssg)
                     text_box.send_keys(Keys.SHIFT, Keys.INSERT)
+                    time.sleep(2)
                     text_box.send_keys(Keys.ENTER)
-                    time.sleep(1)
-                # elif followupmsg != 'error':
-                #     msgbox_xpath = '//div[@title="Type a message"][@role="textbox"]'
-                #     msgbox = browser.find_element('xpath', msgbox_xpath)
-                #     pyperclip.copy(mssg)
-                #     msgbox.send_keys(Keys.SHIFT, Keys.INSERT)
-                #     time.sleep(2)
-                #     msgbox.send_keys(Keys.ENTER)
-                #     time.sleep(1)
-                #     pyperclip.copy(followupmssg)
-                #     msgbox.send_keys(Keys.SHIFT, Keys.INSERT)
-                #     time.sleep(2)
-                #     msgbox.send_keys(Keys.ENTER)
-                #     time.sleep(1)
+                    time.sleep(2)
+
                 else:
                     msgbox_xpath = '//div[@title="Type a message"][@role="textbox"]'
                     msgbox = browser.find_element('xpath', msgbox_xpath)
@@ -99,7 +83,7 @@ def sendmsg(usr, msg, path='error', attach='error'):
                     msgbox.send_keys(Keys.SHIFT, Keys.INSERT)
                     time.sleep(2)
                     msgbox.send_keys(Keys.ENTER)
-                    time.sleep(1)
+                    time.sleep(2)
                     
 
 
@@ -113,4 +97,6 @@ def sendmsg(usr, msg, path='error', attach='error'):
     elif path == 'error':
         print('Please Provide Driver Path')
     else:
-        run()
\ No newline at end of file
+        run()
+
+sendmsg()
\ No newline at end of file
